@@ -1,6 +1,6 @@
 -- |
 -- Module      :  Data.Attoparsec.Types
--- Copyright   :  Bryan O'Sullivan 2011
+-- Copyright   :  Bryan O'Sullivan 2007-2015
 -- License     :  BSD3
 --
 -- Maintainer  :  bos@serpentine.com
@@ -14,6 +14,7 @@ module Data.Attoparsec.Types
     (
       Parser
     , IResult(..)
+    , Chunk(chunkElemToChar)
     ) where
 
-import Data.Attoparsec.Internal.Types (Parser(..), IResult(..))
+import Data.Attoparsec.Internal.Types (Parser(..), IResult(..), Chunk(..))
